@@ -1,4 +1,4 @@
-import json
+import orjson
 from spade.behaviour import OneShotBehaviour
 from driftage.base.conf import getLogger
 
@@ -10,7 +10,7 @@ class SendNewData(OneShotBehaviour):
     async def run(self):
         """[summary]
         """
-        body = json.loads(self.template.body)
+        body = orjson.loads(self.template.body)
         for msg in body:
             if self.agent.sink.is_available():
                 await self.agent.sink.drain(msg)
